### A Pluto.jl notebook ###
# v0.17.0

using Markdown
using InteractiveUtils

# This Pluto notebook uses @bind for interactivity. When running this notebook outside of Pluto, the following 'mock version' of @bind gives bound variables a default value (instead of an error).
macro bind(def, element)
    quote
        local el = $(esc(element))
        global $(esc(def)) = Core.applicable(Base.get, el) ? Base.get(el) : missing
        el
    end
end

# ╔═╡ 5d14c954-4fba-11ec-0eb4-93f700b99fca
begin
	dog = @bind 🐶 html"<input type=number value=0>"
	cat = @bind 🐱 html"<input type=number value=0>"
	rabbit =@bind 🐰 html"<input type=number value=0>"
	dogcat = @bind 🐶🐱 html"<input type=number value=1>"
	dograbbit = @bind 🐶🐰 html"<input type=number value=1>"
	catrabbit = @bind 🐱🐰 html"<input type=number value=1>"
	dogcatrabbit = @bind 🐶🐱🐰 html"<input type=number value=3>"
	
	md"""
	The 3-player **coalitional game** is given by:
	
	{🐶}: $(dog)	
	{🐱}: $(cat)
	{🐰}: $(rabbit)

	{🐶,🐱}: $(dogcat)
	{🐶,🐰}: $(dograbbit)
	{🐱,🐰}: $(catrabbit)

	{🐶,🐱,🐰}: $(dogcatrabbit)
	"""
end

# ╔═╡ 7ba407ce-e71e-4718-a0f7-d2b6d9de3157
Markdown.parse("
This game is **superadditive**:
$((🐶🐱 >= 🐶+🐱) & (🐶🐰 >= 🐶+🐰) & (🐱🐰 >= 🐱+🐰) & (🐶🐱🐰 >= 🐶🐱 + 🐰) & (🐶🐱🐰 >= 🐶🐰 + 🐱) & (🐶🐱🐰 >= 🐱🐰 + 🐶))
")

# ╔═╡ eadc4999-d1d2-4463-bdf5-d064b89568c8
Markdown.parse("
This game is **supermodular**:
$((🐶🐱🐰-🐱🐰 >= 🐶🐰-🐰) & (🐶🐱🐰-🐱🐰 >= 🐶🐱-🐱) & (🐶🐱🐰-🐶🐰 >= 🐶🐱-🐶) & (🐶🐱 >= 🐶+🐱) & (🐶🐰 >= 🐶+🐰) & (🐱🐰 >= 🐱+🐰))
")

# ╔═╡ d60b86e1-a0d5-4a88-aa31-e49db7628aa0
begin
	X = ones(Int64,3,6)
	X[:,1] = [🐶,🐶🐱-🐶,🐶🐱🐰-🐶🐱]
	X[:,2] = [🐶,🐶🐱🐰-🐶🐰,🐶🐰-🐶]
	X[:,3] = [🐶🐱-🐱,🐱,🐶🐱🐰-🐶🐱]
	X[:,4] = [🐶🐱🐰-🐱🐰,🐱,🐱🐰-🐱]
	X[:,5] = [🐶🐰-🐰,🐶🐱🐰-🐶🐰,🐰]
	X[:,6] = [🐶🐱🐰-🐱🐰,🐱🐰-🐰,🐰]
	s = [sum(X[i,:])//6 for i in 1:3]
end;

# ╔═╡ a5ecaa43-5e10-408f-907a-d4006ccc2379
Markdown.parse("
Each **marginal vector** allocates the worth to (🐶,🐱,🐰) for each permutation:

Permutation | Allocation
:------ | :--------:
🐶🐱🐰 | $(X[:,1])
🐶🐰🐱 | $(X[:,2])
🐱🐶🐰 | $(X[:,3])
🐱🐰🐶 | $(X[:,4])
🐰🐶🐱 | $(X[:,5])
🐰🐱🐶 | $(X[:,6])
")

# ╔═╡ e30810c6-3ca7-4ba9-9c82-2cef337366dc
Markdown.parse("
The **Shapley values** of the players (🐶,🐱,🐰) are $s
")

# ╔═╡ Cell order:
# ╟─5d14c954-4fba-11ec-0eb4-93f700b99fca
# ╟─7ba407ce-e71e-4718-a0f7-d2b6d9de3157
# ╟─eadc4999-d1d2-4463-bdf5-d064b89568c8
# ╟─d60b86e1-a0d5-4a88-aa31-e49db7628aa0
# ╟─a5ecaa43-5e10-408f-907a-d4006ccc2379
# ╟─e30810c6-3ca7-4ba9-9c82-2cef337366dc
